@@ -390,7 +390,7 @@ void ExerciseWindow::checkProximity(QString data)
 
 void ExerciseWindow::checkAcc(QString x)
 {
-
+    QDBusMessage reply;
     qDebug () << "checkAcc 1";
     if(x.toInt() > 2200 || x.toInt() < -2200)
     {
@@ -402,6 +402,13 @@ void ExerciseWindow::checkAcc(QString x)
             QObject::connect(tmr, SIGNAL(timeout()), this, SLOT(stopVibrate()));
             tmr->start(1000);  //ndra hr fr olika vibrationslngd
             qDebug () << "checkAcc 2";
+
+            if(set == 1) //last set, unlock!
+            {
+                qDebug () << "checkAcc 3";
+                reply = interface->call(MCE_TKLOCK_MODE_CHANGE_REQ, "unlocked");
+            }
+
             shaked();
         }
 
