@@ -23,7 +23,7 @@ HistoryInfoWindow::HistoryInfoWindow(QWidget *parent) :
     setCentralWidget(widget);
 }
 
-void HistoryInfoWindow::load(QString name, QString group)
+void HistoryInfoWindow::load(QString name, QString group, QString date)
 {
     QList <QString> list;
     int j = 0;
@@ -31,7 +31,7 @@ void HistoryInfoWindow::load(QString name, QString group)
 
     setWindowTitle(name + "/" + group);
 
-    list = xml->getHistoryByExercise(name);
+    list = xml->getHistoryByExercise(name, date);
 
     while(!list.isEmpty())
     {
@@ -42,7 +42,7 @@ void HistoryInfoWindow::load(QString name, QString group)
         else if(list.first() != "0")
             lblSet[j]->setText("Set " + set + ": " + list.takeFirst() + " km on " +
                                 list.takeFirst() + " - " + list.takeFirst());
-        else if(list.first() == "0")
+        else
         {
             list.removeFirst();
             list.removeFirst();
