@@ -166,6 +166,8 @@ void XML::removeHistory(QString name, QString date)
 
 void XML::saveProgram(QString name, QModelIndexList exercises)
 {
+    qDebug() << exercises;
+
     QDomDocument doc( "Program" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/program.xml" );
@@ -223,6 +225,56 @@ void XML::saveProgram(QString name, QModelIndexList exercises)
     return ;
 }
 
+/*QList <QString> XML::removeExistingExercises(QString name, QList <QString> exercises)
+{
+    QList <QString> list;
+    bool found = false;
+    QDomDocument doc( "Program" );
+    QString str = "/home/user/.qexercise";
+    QFile file( str + "/program.xml" );
+    QString tal;
+
+    file.open( QIODevice::ReadWrite );
+    doc.setContent( &file );
+
+    file.close();
+
+    QDomElement root = doc.documentElement();
+
+
+    QDomNode n = root.firstChild();
+    while( !n.isNull() )
+    {
+      QDomElement e = n.toElement();
+      if( !e.isNull() )
+      {
+        if( e.tagName() == "programs" )
+        {
+            if(name == e.attribute( "name", "" ))
+            {
+                for(int i = 0; i < exercises.count(); i++)
+                {
+                    found = false;
+                    for(int j = 1; j < 20; j++)
+                    {
+                        tal.setNum(j);
+                        if(exercises.at(i) == e.attribute("exercise" + tal, ""))
+                        {
+                            found = true;
+                        }
+                    }
+                }
+                if(found == true)
+                    list.append(exercises.at(i));
+            }
+        }
+      }
+      n = n.nextSibling();
+   }
+
+    return list;
+}*/
+
 QDomElement XML::createProgramNode(QDomDocument &d, QString name, QModelIndexList exercises)
 {
     QDomElement cn = d.createElement( "program" );
